@@ -998,11 +998,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 					}
 				}
                 if(option.contains("colspec")){
-                    const QRegularExpression re{"^(.*colspec\\s*[=]\\s*\\{)(.*)\\}"};
-                    const QRegularExpressionMatch match = re.match(option);
-                    if (match.hasMatch()) {
-                        option = match.captured(2);
-                    }
+                    option=LatexTables::handleColSpec(option);
                 }
 				QSet<QString> translationMap=ltxCommands->possibleCommands.value("%columntypes");
 				QStringList res = LatexTables::splitColDef(option);
